# `Object.entries` _(ext/object/entries)_

[Object.entries](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/entries) implementation.

Returns native `Object.entries` if it's implemented, otherwise library implementation is returned

```javascript
const entries = require("ext/object/entries");

entries({ foo: "bar" }); // [["foo", "bar"]]
```
